@@ -443,8 +443,6 @@ class _Parser(object):
     ast = ast.Visit(_PropertyToConstant())
     ast = ast.Visit(_InsertTypeParameters(ast.type_params))
     ast = ast.Visit(_VerifyMutators())
-    # TODO(kramm): This is in the wrong place- it should happen after resolving
-    # local names, in load_pytd.
     ast = ast.Visit(pep484.ConvertTypingToNative(name))
 
     if name:
@@ -669,7 +667,6 @@ class _Parser(object):
     """
     if not self._current_condition.active:
       return
-    # TODO(dbaum): Consider merging this with new_constant().
     alias_or_constant = self.new_alias_or_constant(name_and_value)
     if isinstance(alias_or_constant, pytd.Constant):
       self._constants.append(alias_or_constant)
@@ -985,7 +982,7 @@ class _Parser(object):
     # Extract out abstractmethod and coroutine decorators, there should be at
     # most one remaining decorator.
     def _check_decorator(decorators, decorator_set):
-      exists = any([x in decorators for x in decorator_set])
+      exists = any(x in decorators for x in decorator_set)
       if exists:
         decorators -= decorator_set
       return exists
@@ -993,7 +990,6 @@ class _Parser(object):
         decorators, {"abstractmethod", "abc.abstractmethod"})
     is_coroutine = _check_decorator(
         decorators, {"coroutine", "asyncio.coroutine", "coroutines.coroutine"})
-    # TODO(acaceres): if not inside a class, any decorator should be an error
     if len(decorators) > 1:
       raise ParseError("Too many decorators for %s" % name)
     decorator, = decorators if decorators else (None,)
@@ -1088,8 +1084,8 @@ class _Parser(object):
       class_name: The name of the class (a string).
       parent_args: A list of parent types and (keyword, value) tuples.
           Parent types must be instances of pytd.Type.  Keyword tuples must
-          appear at the end of the list.  Currently the only supported keyword
-          is 'metaclass'.
+          appear at the end of the list.  Currently the only supported keywords
+          are 'total' for TypedDict and 'metaclass'.
       defs: A list of constant (pytd.Constant), function (_NameAndSig), alias
           (pytd.Alias), slot (_SlotDecl), and class (pytd.Class) definitions.
 
@@ -1108,8 +1104,24 @@ class _Parser(object):
     parents = []
     metaclass = None
     namedtuple_index = None
+    found_kwarg = False
     for i, p in enumerate(parent_args):
-      if self._is_parameterized_protocol(p):
+      if p.__class__ is tuple and len(p) == 2:
+        found_kwarg = True
+        keyword, value = p
+        if keyword not in ("metaclass", "total"):
+          raise ParseError("Unexpected classdef kwarg %r" % keyword)
+        elif keyword == "total" and not any(
+            isinstance(parent, pytd.NamedType) and
+            parent.name == "typing.TypedDict" for parent in parents):
+          raise ParseError(
+              "'total' allowed as classdef kwarg only for TypedDict subclasses")
+        if keyword == "metaclass":
+          metaclass = value
+      elif found_kwarg:
+        raise ParseError(
+            "non-keyword arguments cannot follow keyword arguments")
+      elif self._is_parameterized_protocol(p):
         # From PEP 544: "`Protocol[T, S, ...]` is allowed as a shorthand for
         # `Protocol, Generic[T, S, ...]`."
         # https://www.python.org/dev/peps/pep-0544/#generic-protocols
@@ -1117,18 +1129,12 @@ class _Parser(object):
         parents.append(p.Replace(base_type=pytd.NamedType("typing.Generic")))
       elif isinstance(p, pytd.Type):
         parents.append(p)
-      elif p == "NamedTuple":
+      else:
+        assert p == "NamedTuple"
         if namedtuple_index is not None:
           raise ParseError("cannot inherit from bare NamedTuple more than once")
         namedtuple_index = i
         parents.append(p)
-      else:
-        keyword, value = p
-        if i != len(parent_args) - 1:
-          raise ParseError("metaclass must be last argument")
-        if keyword != "metaclass":
-          raise ParseError("Only 'metaclass' allowed as classdef kwarg")
-        metaclass = value
 
     constants, methods, aliases, slots, classes = _split_definitions(defs)
 
@@ -1145,7 +1151,6 @@ class _Parser(object):
                   for name, count in collections.Counter(all_names).items()
                   if count >= 2]
     if duplicates:
-      # TODO(kramm): raise a syntax error right when the identifier is defined.
       raise ParseError("Duplicate identifier(s): " + ", ".join(duplicates))
 
     # This check is performed after the above error checking so that errors
@@ -1178,8 +1183,6 @@ class _Parser(object):
             t = val.type
           constants.append(pytd.Constant(name, t))
 
-    # TODO(dbaum): Is NothingType even legal here?  The grammar accepts it but
-    # perhaps it should be a ParseError.
     parents = [p for p in parents if not isinstance(p, pytd.NothingType)]
     methods = _merge_method_signatures(methods)
     if not parents and class_name not in ["classobj", "object"]:
@@ -1333,8 +1336,6 @@ def _validate_params(param_list):
     ParseError: if special arguments are present in the wrong positions or
         combinations.
   """
-  # TODO(kramm): Disallow "self" and "cls" as names for param (if it's not
-  # the first parameter).
 
   params = []
   has_bare_star = False
@@ -1348,9 +1349,6 @@ def _validate_params(param_list):
         raise ParseError("ellipsis (...) must be last parameter")
       if has_bare_star:
         raise ParseError("ellipsis (...) not compatible with bare *")
-      # TODO(dbaum): Shouldn't we pass the existing parameter names to
-      # InventStarArgParams()?  The legacy parser doesn't, so leaving the
-      # code identical to legacy for now.
       stararg, starstararg = visitors.InventStarArgParams([])
       continue
 
@@ -1415,7 +1413,6 @@ def _starstar_param(name, param_type):
 
 def _type_for_default(default):
   """Return a pytd type object for the given default value."""
-  # TODO(kramm): We should use __builtin__ types here. (And other places)
   if default == "None":
     return pytd.NamedType("NoneType")
   elif isinstance(default, float):
